/* -*- mode:c; coding:utf-8; tab-width:8; c-basic-offset:4; indent-tabs-mode:nil -*- */
/*
  Copyright (c) 2003-2004 MacUIM contributors and others
  http://www.digital-genes.com/~yatsu/macuim/

  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:

  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
  3. Neither the name of authors nor the names of its contributors
     may be used to endorse or promote products derived from this software
     without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
  ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  SUCH DAMAGE.
*/

#ifndef __CANDIDATE_CARBON_H__
#define __CANDIDATE_CARBON_H__

#include "MUIM.h"


#define NR_CANDIDATES         10
#define DEFAULT_SEPARATOR_STR "|"


void
LayoutCandidate(MUIMSessionHandle inHandle);

OSStatus
InitCandidateWindow(MUIMSessionHandle inHandle);

OSStatus
ShowCandidateWindow(MUIMSessionHandle inHandle, TSMStat *inTSMStat);

OSStatus
HideCandidateWindow(MUIMSessionHandle inHandle);

Boolean
CandidateWindowIsVisible(MUIMSessionHandle inHandle);

OSStatus
SetCandidateFont(MUIMSessionHandle inHandle, CFStringRef name, float size);

OSStatus
ShowModeTips(MUIMSessionHandle inHandle, CFArrayRef inLines);

OSStatus
HideModeTips(MUIMSessionHandle inHandle);


#endif  /* __CANDIDATE_CARBON_H__ */
